# lite-sandbox

An experimental Python package for sandboxing plugin scripts inside of Python by controlling imports and access to risky modules.

## Current Status
Currently in the initial planning and testing phase. This is nothing more than a proof of concept and shouldn't be used in production